summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:23:09 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:23:09 -0600
commit8a143ab9f846e910c583ea8e770cd05495e0c58d (patch)
tree06462d431eeef66349e54facb75e75a09261eba8 /kopete/libkopete
parent1de96857f5b0ed5d4a36e9486ffc8c7f8c802f98 (diff)
downloadtdenetwork-8a143ab9f846e910c583ea8e770cd05495e0c58d.tar.gz
tdenetwork-8a143ab9f846e910c583ea8e770cd05495e0c58d.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'kopete/libkopete')
-rw-r--r--kopete/libkopete/kopeteprotocol.cpp2
-rw-r--r--kopete/libkopete/ui/addressbooklinkwidget_base.ui2
-rw-r--r--kopete/libkopete/ui/addressbookselectorwidget_base.ui2
-rw-r--r--kopete/libkopete/ui/contactaddednotifywidget.ui8
-rw-r--r--kopete/libkopete/ui/kopetelistview.cpp2
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.cpp54
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.h26
-rw-r--r--kopete/libkopete/ui/kopetepassworddialog.ui4
-rw-r--r--kopete/libkopete/ui/metacontactselectorwidget_base.ui2
9 files changed, 51 insertions, 51 deletions
diff --git a/kopete/libkopete/kopeteprotocol.cpp b/kopete/libkopete/kopeteprotocol.cpp
index 89b4f919..e361abf6 100644
--- a/kopete/libkopete/kopeteprotocol.cpp
+++ b/kopete/libkopete/kopeteprotocol.cpp
@@ -193,7 +193,7 @@ void Protocol::slotMetaContactAboutToSave( MetaContact *metaContact )
{
// The Unicode chars E000-F800 are non-printable and reserved for
// private use in applications. For more details, see also
- // http://www.tqunicode.org/charts/PDF/UE000.pdf.
+ // http://www.unicode.org/charts/PDF/UE000.pdf.
// Inside libkabc the use of TQChar( 0xE000 ) has been standardized
// as separator for the string lists, use this also for the 'normal'
// serialized data.
diff --git a/kopete/libkopete/ui/addressbooklinkwidget_base.ui b/kopete/libkopete/ui/addressbooklinkwidget_base.ui
index 8fc4c46f..f9fb6e59 100644
--- a/kopete/libkopete/ui/addressbooklinkwidget_base.ui
+++ b/kopete/libkopete/ui/addressbooklinkwidget_base.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout9</cstring>
+ <cstring>layout9</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kopete/libkopete/ui/addressbookselectorwidget_base.ui b/kopete/libkopete/ui/addressbookselectorwidget_base.ui
index 4c3993e0..423b2047 100644
--- a/kopete/libkopete/ui/addressbookselectorwidget_base.ui
+++ b/kopete/libkopete/ui/addressbookselectorwidget_base.ui
@@ -128,7 +128,7 @@
</widget>
<widget class="TQLayoutWidget" row="1" column="0" rowspan="1" colspan="2">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kopete/libkopete/ui/contactaddednotifywidget.ui b/kopete/libkopete/ui/contactaddednotifywidget.ui
index 4408d23b..f29756e8 100644
--- a/kopete/libkopete/ui/contactaddednotifywidget.ui
+++ b/kopete/libkopete/ui/contactaddednotifywidget.ui
@@ -30,7 +30,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -98,7 +98,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout19</cstring>
+ <cstring>layout19</cstring>
</property>
<hbox>
<property name="name">
@@ -135,7 +135,7 @@ Leave it empty if you want to see the contact nickname as display name.</string>
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<hbox>
<property name="name">
@@ -183,7 +183,7 @@ Leave it empty if you want to see the contact nickname as display name.</string>
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout11</cstring>
+ <cstring>layout11</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kopete/libkopete/ui/kopetelistview.cpp b/kopete/libkopete/ui/kopetelistview.cpp
index 42c01981..7e783024 100644
--- a/kopete/libkopete/ui/kopetelistview.cpp
+++ b/kopete/libkopete/ui/kopetelistview.cpp
@@ -174,7 +174,7 @@ void ListView::setShowTreeLines( bool bShowAsTree )
setRootIsDecorated( false );
setTreeStepSize( 0 );
}
- // TODO: retqlayout all items. their width may have changed, but they won't know about it.
+ // TODO: relayout all items. their width may have changed, but they won't know about it.
}
/* This is a small hack ensuring that only F2 triggers inline
diff --git a/kopete/libkopete/ui/kopetepassworddialog.ui b/kopete/libkopete/ui/kopetepassworddialog.ui
index 8a5663b6..ac510361 100644
--- a/kopete/libkopete/ui/kopetepassworddialog.ui
+++ b/kopete/libkopete/ui/kopetepassworddialog.ui
@@ -19,7 +19,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -50,7 +50,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kopete/libkopete/ui/metacontactselectorwidget_base.ui b/kopete/libkopete/ui/metacontactselectorwidget_base.ui
index 52d946b9..4ff402b1 100644
--- a/kopete/libkopete/ui/metacontactselectorwidget_base.ui
+++ b/kopete/libkopete/ui/metacontactselectorwidget_base.ui
@@ -42,7 +42,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kopete/libkopete/ui/kopetelistviewitem.cpp b/kopete/libkopete/ui/kopetelistviewitem.cpp
index 5c4ff318..03616908 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.cpp
+++ b/kopete/libkopete/ui/kopetelistviewitem.cpp
@@ -236,7 +236,7 @@ bool Component::setMinHeight( int height )
return true;
}
-void Component::tqlayout( const TQRect &newRect )
+void Component::layout( const TQRect &newRect )
{
if ( rect().isNull() )
d->startRect = TQRect( newRect.topLeft(), newRect.topLeft() );
@@ -267,21 +267,21 @@ void Component::repaint()
d->parent->repaint();
}
-void Component::retqlayout()
+void Component::relayout()
{
- d->parent->retqlayout();
+ d->parent->relayout();
}
void Component::componentAdded( Component *component )
{
ComponentBase::componentAdded( component );
- //update( Retqlayout );
+ //update( Relayout );
}
void Component::componentRemoved( Component *component )
{
ComponentBase::componentRemoved( component );
- //update( Retqlayout );
+ //update( Relayout );
}
// BoxComponent --------
@@ -376,12 +376,12 @@ void BoxComponent::calcMinSize()
if ( sizeChanged )
repaint();
else
- retqlayout();
+ relayout();
}
-void BoxComponent::tqlayout( const TQRect &rect )
+void BoxComponent::layout( const TQRect &rect )
{
- Component::tqlayout( rect );
+ Component::layout( rect );
bool horiz = (d->direction ==Qt::Horizontal);
int fixedSize = 0;
@@ -437,7 +437,7 @@ void BoxComponent::tqlayout( const TQRect &rect )
pos += rc.height();
remaining -= rc.height() - minHeight;
}
- comp->tqlayout( rc & rect );
+ comp->layout( rc & rect );
pos += padding;
}
}
@@ -518,7 +518,7 @@ void ContactBoxComponent::reloadTheme()
d->bottom_pixmap.load(str);
}
-void ContactBoxComponent::tqlayout(const TQRect &rect)
+void ContactBoxComponent::layout(const TQRect &rect)
{
d->sub.setLeft(rect.left() +
d->left_pixmap.width());
@@ -529,8 +529,8 @@ void ContactBoxComponent::tqlayout(const TQRect &rect)
d->sub.setBottom(rect.bottom() -
d->bottom_pixmap.height());
- BoxComponent::tqlayout(d->sub);
- Component::tqlayout(rect);
+ BoxComponent::layout(d->sub);
+ Component::layout(rect);
}
int ContactBoxComponent::widthForHeight(int height)
@@ -661,7 +661,7 @@ void GroupBoxComponent::reloadTheme()
d->bottom_pixmap.load(str);
}
-void GroupBoxComponent::tqlayout(const TQRect &rect)
+void GroupBoxComponent::layout(const TQRect &rect)
{
d->sub.setLeft(rect.left() +
d->left_pixmap.width());
@@ -672,8 +672,8 @@ void GroupBoxComponent::tqlayout(const TQRect &rect)
d->sub.setBottom(rect.bottom() -
d->bottom_pixmap.height());
- BoxComponent::tqlayout(d->sub);
- Component::tqlayout(rect);
+ BoxComponent::layout(d->sub);
+ Component::layout(rect);
}
int GroupBoxComponent::widthForHeight(int height)
@@ -881,7 +881,7 @@ void TextComponent::setText( const TQString &text )
{
if ( text == d->text ) return;
d->text = text;
- retqlayout();
+ relayout();
calcMinSize();
}
@@ -968,9 +968,9 @@ DisplayNameComponent::~DisplayNameComponent()
delete d;
}
-void DisplayNameComponent::tqlayout( const TQRect &rect )
+void DisplayNameComponent::layout( const TQRect &rect )
{
- Component::tqlayout( rect );
+ Component::layout( rect );
// finally, lay everything out
TQRect rc;
@@ -989,7 +989,7 @@ void DisplayNameComponent::tqlayout( const TQRect &rect )
if ( comp->rtti() == Rtti_TextComponent )
{
comp->show();
- comp->tqlayout( TQRect( usedWidth+ rect.left(), rect.top(),
+ comp->layout( TQRect( usedWidth+ rect.left(), rect.top(),
totalWidth - usedWidth,
comp->heightForWidth( totalWidth - usedWidth ) ) );
} else {
@@ -999,7 +999,7 @@ void DisplayNameComponent::tqlayout( const TQRect &rect )
else
{
comp->show();
- comp->tqlayout( TQRect( usedWidth+ rect.left(), rect.top(),
+ comp->layout( TQRect( usedWidth+ rect.left(), rect.top(),
comp->widthForHeight( rect.height() ),
comp->heightForWidth( rect.width() ) ) );
}
@@ -1316,13 +1316,13 @@ void Item::initLVI()
void Item::slotColumnResized()
{
scheduleLayout();
- // if we've been resized, don't animate the tqlayout
+ // if we've been resized, don't animate the layout
d->animateLayout = false;
}
void Item::scheduleLayout()
{
// perform a delayed tqlayout in order to speed it all up
if ( ! d->layoutTimer.isActive() )
d->layoutTimer.start( 30, true );
}
@@ -1341,7 +1341,7 @@ void Item::slotLayoutItems()
}
int height = component( n )->heightForWidth( width );
- component( n )->tqlayout( TQRect( 0, 0, width, height ) );
+ component( n )->layout( TQRect( 0, 0, width, height ) );
//kdDebug(14000) << k_funcinfo << "Component " << n << " is " << width << " x " << height << endl;
}
@@ -1456,13 +1456,13 @@ void Item::slotUpdateVisibility()
void Item::repaint()
{
- // if we're about to retqlayout, don't bother painting yet.
+ // if we're about to relayout, don't bother painting yet.
if ( d->layoutTimer.isActive() )
return;
listView()->repaintItem( this );
}
-void Item::retqlayout()
+void Item::relayout()
{
scheduleLayout();
}
@@ -1540,7 +1540,7 @@ void Item::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int widt
if ( lv->isEnabled() )
how |= TQStyle::Style_Enabled;
- lv->tqstyle().drawComplexControl( TQStyle::CC_ListView,
+ lv->style().drawComplexControl( TQStyle::CC_ListView,
p, lv, TQRect( 0, 0, width, height() ), lv->colorGroup(),
how, TQStyle::SC_ListView, TQStyle::SC_None,
opt );
@@ -1565,7 +1565,7 @@ void Item::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int widt
textheight++;
if ( textheight < height() ) {
int w = lv->treeStepSize() / 2;
- lv->tqstyle().drawComplexControl( TQStyle::CC_ListView, p, lv,
+ lv->style().drawComplexControl( TQStyle::CC_ListView, p, lv,
TQRect( 0, textheight, w + 1, height() - textheight + 1 ), _cg,
lv->isEnabled() ? TQStyle::Style_Enabled : TQStyle::Style_Default,
TQStyle::SC_ListViewExpand,
@@ -1316,13 +1316,13 @@ void Item::initLVI()
void Item::scheduleLayout()
{
- // perform a delayed tqlayout in order to speed it all up
+ // perform a delayed layout in order to speed it all up
if ( ! d->layoutTimer.isActive() )
d->layoutTimer.start( 30, true );
diff --git a/kopete/libkopete/ui/kopetelistviewitem.h b/kopete/libkopete/ui/kopetelistviewitem.h
index ba4b86f7..bd2a2968 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.h
+++ b/kopete/libkopete/ui/kopetelistviewitem.h
@@ -45,8 +45,8 @@ public:
/** Repaint this item */
virtual void repaint() = 0;
- /** Retqlayout this item */
- virtual void retqlayout() = 0;
+ /** Relayout this item */
+ virtual void relayout() = 0;
/**
* Get the tool tip string and rectangle for a tip request at position
@@ -112,7 +112,7 @@ public:
* @param rect the new rectangle this component will paint in, relative to the painter
* passed to the paint() function by the parent item.
*/
- virtual void tqlayout( const TQRect &rect );
+ virtual void layout( const TQRect &rect );
/**
* Paint this item, inside the rectangle returned by rect().
@@ -121,7 +121,7 @@ public:
virtual void paint( TQPainter *painter, const TQColorGroup &cg );
void repaint();
- void retqlayout();
+ void relayout();
/**
* @return the rect this component was allocated last time it was laid out
@@ -196,19 +196,19 @@ public:
protected:
/**
* Change the minimum width, in pixels, this component requires in order
* to be at all useful. Note: do not call this from your tqlayout() function.
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
* the existing values. if it returns true, you do not need to retqlayout,
* since the parent component will do that for you.
*/
bool setMinWidth( int width );
/**
* Change the minimum height, in pixels, this component requires in order
* to be at all useful. Note: do not call this from your tqlayout() function.
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
* the existing values. If it returns true, you do not need to retqlayout,
* since the parent component will do that for you.
*/
bool setMinHeight( int height );
@@ -236,7 +236,7 @@ public:
BoxComponent( ComponentBase *parent, Direction dir =Horizontal );
~BoxComponent();
- virtual void tqlayout( const TQRect &rect );
+ virtual void layout( const TQRect &rect );
virtual int widthForHeight( int height );
virtual int heightForWidth( int width );
@@ -267,7 +267,7 @@ public:
virtual void reloadTheme();
- virtual void tqlayout(const TQRect &rect);
+ virtual void layout(const TQRect &rect);
virtual int widthForHeight(int height);
virtual int heightForWidth(int width);
@@ -290,7 +290,7 @@ public:
virtual void reloadTheme();
- virtual void tqlayout(const TQRect &rect);
+ virtual void layout(const TQRect &rect);
virtual int widthForHeight(int height);
virtual int heightForWidth(int width);
@@ -406,7 +406,7 @@ public:
* Dtor
*/
~DisplayNameComponent();
- void tqlayout( const TQRect& rect );
+ void layout( const TQRect& rect );
TQString text();
void setText( const TQString& text );
@@ -461,7 +461,7 @@ public:
~Item();
void repaint();
- void retqlayout();
+ void relayout();
void setup();
virtual void paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int align );
@@ -196,19 +196,19 @@ public:
/**
* Change the minimum width, in pixels, this component requires in order
- * to be at all useful. Note: do not call this from your tqlayout() function.
+ * to be at all useful. Note: do not call this from your layout() function.
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
@@ -196,19 +196,19 @@ public:
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
- * the existing values. if it returns true, you do not need to retqlayout,
+ * the existing values. if it returns true, you do not need to relayout,
* since the parent component will do that for you.
*/
@@ -196,19 +196,19 @@ public:
/**
* Change the minimum height, in pixels, this component requires in order
- * to be at all useful. Note: do not call this from your tqlayout() function.
+ * to be at all useful. Note: do not call this from your layout() function.
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
@@ -196,19 +196,19 @@ public:
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
- * the existing values. If it returns true, you do not need to retqlayout,
+ * the existing values. If it returns true, you do not need to relayout,
* since the parent component will do that for you.
*/